Hashcash
========

A Python implementation of the Hashcash proof-of-work algorithm for email.  This is the reference (?) Python implementation from [hashcash.org](http://www.hashcash.org/libs/python/), modified lightly for Python 3 compatibility and packaging.  It's been used as a milter with Postfix, and probably has other uses as well.
